Pykaryote Documentation — Pykaryote 1.1.0d documentation

### Navigation

- index
- modules |
- next |
- Pykaryote 1.1.0d documentation »

# Pykaryote Documentation

This documentation aims to be a comprehensive guide to Pykaryote, a computer model for simulating the evolution of biological complexity. It serves as a guide for both users and developers.

## Tutorial

The tutorial introduces the Pykaryote model and describes how to install and run Pykaryote.

- Introduction
  - What is Pykaryote
  - Scientific Background
- Installing Pykaryote
  - Supported Platforms
  - Dependencies
  - Installing (Linux)
  - Installing (Other Platforms)
- Running Pykaryote
  - Setting Up Simulations
  - Simulations and Comparisons
  - Command Line Tools
  - Deprecated Scripts
- Using Petri
  - Running with MPI
  - The `run` Command
  - The `batch` Command
  - The `graph` Command
- Deprecated Scripts
  - pyk-run
  - pyk-mass_run
  - pyk-analyze
  - pyk-compare
  - pyk-comparison-graph

## Developer Guide

This guide is for developers who wish to contribute to Pykaryote. It describes the tools and work flow associated with modifying and building Pykaryote.

- Installing for Development
  - Installing Dependencies
  - Getting the Source Code
  - Building
  - Testing
- Package Contents
  - Root Directory
  - Pykaryote Package
- Development Workflow
  - Git
  - Coding Style
  - Adding Configuration Options
  - Unit Testing
  - Profiling
  - Documentation
  - Packaging for Release

## Reference Manual

This document describes the design of Pykaryote. It provides a detailed description of Pykaryote’s organisms, their genomes and configuration options, as well as a high level description of the program design.

- The Model in Depth
  - Terms
  - The Life of an Organism
  - Genome
- Simulation Configuration Files
  - Configuration Options
- Analyzer Data File Format
  - The Analyzer Directory
  - The Comparative-Analyzer Directory
- Other Configuration Files
  - Comparison Configuration Files
  - Petri Settings Configuration Files
  - Petri Batch Configuration Files
- Modules
  - Pykaryote.sim
  - Pykaryote.petri
  - Pykaryote.utils
  - Pykaryote.test

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Pykaryote 1.1.0d documentation »